<?php
/**
 * Main application class
 *
 * @package wp-slideshow-master
 * @author InstaProduct
 * @link http://insta-product.com/
 */

//
//Include all function files
require_once( IPSWB_LIB . '/config.php' );
require_once( IPSWB_LIB . '/setting.php' );
require_once( IPSWB_LIB . '/db.php' );
require_once( IPSWB_LIB . '/font.php' );
require_once( IPSWB_LIB . '/faicon.php' );
require_once( IPSWB_LIB . '/model.php' );
require_once( IPSWB_LIB . '/modelBox.php' );
require_once( IPSWB_LIB . '/modelStyle.php' );
require_once( IPSWB_LIB . '/modelStat.php' );
require_once( IPSWB_LIB . '/list.php' );
require_once( IPSWB_APP . '/controller.php' );
require_once( IPSWB_APP . '/viewer.php' );
require_once( IPSWB_LIB . '/factory.php' );
require_once( IPSWB_LIB . '/factoryPage.php' );

//Color library
if ( ! class_exists( 'phpColor' )) {
	require_once( IPSWB_LIB . '/Color.php' );
}

if ( ! class_exists( 'IPSwb_App' ))
{
	class IPSwb_App
	{
		//{{ run

		/**
		 * Run all functions
		 *
		 * @return void
		 */
		public static function run()
		{
			$hook = sanitize_title( IPSWB_TITLE );

			//Install Plugin
			register_activation_hook( __FILE__, array( __CLASS__, 'install' ) );

			//Hook for plugin loaded
			add_action( 'plugins_loaded', array( __CLASS__, 'updateDb' ) );

			//
			//Admin init
			add_action( 'admin_init', array( __CLASS__, 'adminInit' ) );

			//
			//Register post type
			add_action( 'init', array( __CLASS__, 'registerPostType' ) );

			//
			//Register admin menu
			add_action( 'admin_menu', array( __CLASS__, 'addAdminMenu' ) );

			//
			//Shortcode setup
			//
			// Add generator shortcode button
			add_action( 'init', array( __CLASS__, 'addShortcodeEditorButton' ), 100 );
			// Add pop up content
			add_filter( 'the_editor', array( __CLASS__, 'shortcodeEditorFilter' ) );
			add_action( 'admin_footer', array( __CLASS__, 'addShortcodeForm' ) );
			//Add Shortcode
			add_shortcode( 'wp_slideshow_master', array( __CLASS__, 'shortcode' ) );

			//
			//Rewrite Handler
			//
			add_action( 'init', array( __CLASS__, 'rewriteFlush' ) );
			add_action( 'pre_get_posts', array( __CLASS__, 'init' ) );

			//Render page
			add_action( 'template_redirect', array( __CLASS__, 'factoryPage' ) );

			//
			//Add css
			add_action(
				'admin_print_styles-toplevel_page_' . IPSWB_PAGENAME,
				array( __CLASS__, 'adminStyle' ),
				1100
			);
			add_action(
				'admin_print_styles-'.$hook.'_page_' . IPSWB_PAGENAME . '-create',
				array( __CLASS__, 'adminStyle' ),
				1100
			);
			add_action(
				'admin_print_styles-'.$hook.'_page_' . IPSWB_PAGENAME . '-style',
				array( __CLASS__, 'adminStyle' ),
				1100
			);
			/*add_action(
				'admin_print_styles-'.$hook.'_page_' . IPSWB_PAGENAME . '-setting',
				array( __CLASS__, 'adminStyle' ),
				1100
			);*/
			add_action(
				'admin_print_styles',
				array( __CLASS__, 'adminGlobalStyle' ),
				1000
			);

			//
			//Add javascript
			add_action(
				'admin_print_scripts-toplevel_page_' . IPSWB_PAGENAME,
				array( __CLASS__, 'adminScript' ),
				1100
			);
			add_action(
				'admin_print_scripts-'.$hook.'_page_'.IPSWB_PAGENAME. '-create',
				array( __CLASS__, 'adminScript' ),
				1100
			);
			add_action(
				'admin_print_scripts-'.$hook.'_page_'.IPSWB_PAGENAME. '-style',
				array( __CLASS__, 'adminScript' ),
				1100
			);
			/*add_action(
				'admin_print_scripts-'.$hook.'_page_'.IPSWB_PAGENAME. '-setting',
				array( __CLASS__, 'adminScript' ),
				1100
			);*/
			add_action(
				'admin_print_scripts',
				array( __CLASS__, 'adminGlobalScript' ),
				1000
			);

			//
			//Front style & script
			add_action('wp_head', array( __CLASS__, 'publicStyle' ) );

			if ( ! is_admin() ) {
				add_action('wp_enqueue_scripts', array( __CLASS__, 'publicScript' ), 10 );
			}
		}

		//}}
		//{{ install

		/**
		 * Install plugin
		 *
		 * @return void
		 */
		public static function install()
		{
			//Install DB
			$db = new IPSwb_Db();
			$db->install();
		}

		//}}
		//{{ updateDb

		/**
		 * Update Db
		 *
		 * @return void
		 */
		public static function updateDb()
		{
			$db = new IPSwb_Db();
			$db->update();
		}

		//}}
		//{{ adminInit

		/**
		 * Admin init
		 *
		 * @return void
		 */
		public static function adminInit()
		{
			/**
			 * Ajax handler
			 **/
			$controller = new IPSwb_Controller();
			$controller->ajax();
		}

		//}}
		//{{ registerPostType

		/**
		 * Register Post Type
		 *
		 * @return void
		 */
		public static function registerPostType()
		{
			$args	= array(
				'public' => false
			);
			register_post_type( 'ipswb_box_page', $args );
		}

		//}}
		//{{ addAdminMenu

		/**
		 * Add admin menu
		 *
		 * @return void
		 */
		public static function addAdminMenu()
		{
			add_menu_page(
				IPSWB_TITLE,
				IPSWB_TITLE,
				'edit_posts',
				IPSWB_PAGENAME,
				array( __CLASS__, 'dashboard' ),
				'dashicons-slides'
			);
			add_submenu_page(
				IPSWB_PAGENAME,
				__( 'All Slideshows', IPSWB_SLUG ),
				__( 'All Slideshows', IPSWB_SLUG ),
				'edit_posts',
				IPSWB_PAGENAME,
				array( __CLASS__, 'dashboard' )
			);
			add_submenu_page(
				IPSWB_PAGENAME,
				__( 'Add Slideshow', IPSWB_SLUG ),
				__( 'Add Slideshow', IPSWB_SLUG ),
				'edit_posts',
				IPSWB_PAGENAME . '-create',
				array( __CLASS__, 'create' )
			);
			add_submenu_page(
				IPSWB_PAGENAME,
				__( 'Slideshow Styles', IPSWB_SLUG ),
				__( 'Slideshow Styles', IPSWB_SLUG ),
				'edit_posts',
				IPSWB_PAGENAME . '-style',
				array( __CLASS__, 'style' )
			);
			/*add_submenu_page(
				IPSWB_PAGENAME,
				__( 'Settings', IPSWB_SLUG ),
				__( 'Settings', IPSWB_SLUG ),
				'edit_posts',
				IPSWB_PAGENAME . '-setting',
				array( __CLASS__, 'setting' )
			);*/
		}

		//}}
		//{{ dashboard

		/**
		 * Manage all boxes
		 *
		 * @return void
		 */
		public static function dashboard()
		{
			$viewer = new IPSwb_Viewer();
			$viewer->dashboard();
		}

		//}}
		//{{ create

		/**
		 * Create new box
		 *
		 * @return void
		 */
		public static function create()
		{
			$viewer = new IPSwb_Viewer();
			$viewer->create();
		}

		//}}
		//{{ style

		/**
		 * Manage box styles
		 *
		 * @return void
		 */
		public static function style()
		{
			$viewer = new IPSwb_Viewer();
			$viewer->style();
		}

		//}}
		//{{ setting

		/**
		 * Add administrator setting page
		 *
		 * @return void
		 */
		public static function setting()
		{
			$viewer = new IPSwb_Viewer();
			$viewer->setting();
		}

		//}}
		//{{ factory

		/**
		 * Render promo page
		 *
		 * @return void
		 */
		public static function factory()
		{
			//Factory
			$factory = new IPSwb_Factory();
			$factory->render();
		}

		//}}
		//{{ addShortcodeEditorButton

		/**
		 * Add shortcode button in content editor
		 *
		 * @return void
		 */
		public static function addShortcodeEditorButton()
		{
			if ( ! current_user_can('edit_posts') && ! current_user_can('edit_pages') ) {
				return;
			}
			if ( get_user_option('rich_editing') == 'true') {
				add_filter( 'mce_external_plugins', array( __CLASS__, 'addTinymcePlugin' ));
				add_filter( 'mce_buttons', array( __CLASS__, 'registerTinymceButton' ));
			}
		}

		//}}
		//{{ addTinymcePlugin

		/**
		 * Add tinyMce plugin
		 *
		 * @return void
		 */
		public static function addTinymcePlugin( $plugin_array )
		{
			$plugin_array['ipswb_shortcode'] = IPSWB_BASE_URL . '/assets/js/editor-plugin.js';
			return $plugin_array;
		}

		//}}
		//{{ registerTinymceButton

		/**
		 * Add tinyMce button
		 *
		 * @return void
		 */
		public static function registerTinymceButton( $buttons )
		{
			array_push($buttons, "|", "ipswb_shortcode");
			return $buttons;
		}

		//}}
		//{{ shortcodeEditorFilter

		/**
		 * The editor filter
		 *
		 * @param  string $content
		 * @return string
		 */
		public static function shortcodeEditorFilter( $content )
		{
			global $ipswb_useEditor;
			$ipswb_useEditor = true;
			return $content;
		}

		//}}
		//{{ addShortcodeForm

		/**
		 * Add shortcode form
		 *
		 * @return void
		 */
		public static function addShortcodeForm()
		{
			global $ipswb_useEditor;

			if ( $ipswb_useEditor ) {
				$viewer = new IPSwb_Viewer();
				$viewer->shortcodeBackend();
			}
		}

		//}}
		//{{ shortcode

		/**
		 * Render shortcode
		 *
     * @param  array  $atts
     * @param  string $content
		 * @return void
		 */
		public static function shortcode( $atts, $content = '' )
		{
			$factory = new IPSwb_Factory( $atts );
			return $factory->render();
		}

		//}}
		//{{ init

		/**
		 * Init request
		 *
		 * @return void
		 */
		public static function init( $query )
		{
			$q = $query->query;
			if ( isset( $q['ipswb'] ) && isset( $q['box_name'] )) {
				$query->query_vars['post_type'] = 'ipswb_box';
				$query->query_vars['name']      = $q['box_name'];
				$query->query_vars['pagename']  = $q['box_name'];
				$query->query['pagename']       = $q['box_name'];

			} elseif( isset( $q['box_id'] )) {
				$query->query_vars['post_type'] = 'ipswb_box';
				$query->query_vars['p']         = absint( $q['box_id'] );
			}
		}

		//}}
		//{{ rewriteInit

		/**
		 * Init rewrite rule
		 *
		 * @return void
		 */
		public static function rewriteInit()
		{
			$base = get_option( '__ipswb_base_path', 'box-page' );
			add_rewrite_rule(
			 $base . '/([^/]+)/?$',
			 'index.php?ipswb=1&box_name=$matches[1]',
			 'top'
			);
			add_rewrite_rule(
			 $base . '/([^/]+)/feed/(feed|rdf|rss|rss2|atom)/?$',
			 'index.php?ipswb=1&box_name=$matches[1]&feed=$matches[2]',
			 'top'
			);
			add_rewrite_rule(
				$base . '/([^/]+)/(feed|rdf|rss|rss2|atom)/?$',
				'index.php?ipswb=1&box_name=$matches[1]&feed=$matches[2]',
				'top'
			);
			add_rewrite_rule(
				$base . '/([^/]+)/page/?([0-9]{1,})/?$',
				'index.php?ipswb=1&box_name=$matches[1]&paged=$matches[2]',
				'top'
			);
			add_rewrite_tag( '%box_name%', '([a-zA-Z0-9\_])');
			add_rewrite_tag( '%box_id%', '([0-9])');
			add_rewrite_tag( '%ipswb%', '([1])');
		}

		//}}
		//{{ rewriteFlush

		/**
		 * Flush rewrite rule
		 *
		 * @return void
		 */
		public static function rewriteFlush()
		{
			$base = get_option( '__ipswb_base_path', 'box-page' );
			$old  = get_option( '__ipswb_base_path_old', 'box-page' );

			self::rewriteInit();

			if ( $base != $old ) {
				 flush_rewrite_rules();
				 update_option( '__ipswb_base_path_old', $base );
			}
		}

		//}}
		//{{ factoryPage

		/**
		 * Render result page
		 *
		 * @return void
		 */
		public static function factoryPage()
		{
			//Factory
			$factory = new IPSwb_Factory_Page();
			$factory->render();
		}

		//}}
		//{{ adminStyle

		/**
		 * Add Css file
		 *
		 * @return void
		 */
		public static function adminStyle()
		{
			/*wp_enqueue_style('ip-owl-style');
			wp_deregister_style( 'ip-owl-style' );
			wp_register_style(
				'ip-owl-style',
				IPSWB_BASE_URL . 'assets/css/owl.carousel.css',
				false,
				null
			);
			wp_enqueue_style('ip-owl-style');

			wp_enqueue_style('ip-bxslider-style');
			wp_deregister_style( 'ip-bxslider-style' );
			wp_register_style(
				'ip-bxslider-style',
				IPSWB_BASE_URL . 'assets/css/jquery.bxslider.css',
				false,
				null
			);
			wp_enqueue_style('ip-bxslider-style');*/

			wp_deregister_style( 'ipswb-admin-style' );
			wp_register_style(
				'ipswb-admin-style',
				IPSWB_BASE_URL . 'assets/css/admin.min.css',
				false,
				null
			);
			wp_enqueue_style('ipswb-admin-style');
		}

		//}}
		//{{ adminGlobalStyle

		/**
		 * Add Css file to all pages
		 *
		 * @return void
		 */
		public static function adminGlobalStyle()
		{
			wp_deregister_style( 'ipswb-admin-global-style' );
			wp_register_style(
				'ipswb-admin-global-style',
				IPSWB_BASE_URL . 'assets/css/admin-global.min.css',
				false,
				null
			);
			wp_enqueue_style('ipswb-admin-global-style');
		}

		//}}
		//{{ adminScript

		/**
		 * Add javascript file
		 *
		 * @return void
		 */
		public static function adminScript()
		{
		?>
			<script type="text/javascript">
				var ipswb_img_url = '<?php echo IPSWB_BASE_URL . 'assets/img/'; ?>',
					ui_base_image	= '<?php echo IPSWB_BASE_URL . 'assets/img/'; ?>',
					ui_message		 =
					{
						delete_confirm_title: '<?php _e( 'Delete Confirmation', IPSWB_SLUG ); ?>',
						delete_confirm_info: '<?php _e( 'Are you sure doing this action?', IPSWB_SLUG ); ?>'
					}
			</script>

			<?php
			wp_deregister_script('jquery-ui');
			wp_register_script(
				'jquery-ui',
				"http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jqueryui/1.10.4/jquery-ui.min.js",
				false,
				null
			);
			wp_enqueue_script('jquery-ui');

      /*wp_deregister_script('ip-velocity-script');
      wp_enqueue_script(
        'ip-velocity-script',
        IPSWB_BASE_URL . 'assets/js/public/velocity.min.js',
        array(),
        1,
        true
      );

      wp_deregister_script('ip-velocity-ui-script');
      wp_enqueue_script(
        'ip-velocity-ui-script',
        IPSWB_BASE_URL . 'assets/js/public/velocity.ui.js',
        array(),
        1,
        true
      );

      wp_deregister_script('ip-owl-script');
      wp_enqueue_script(
        'ip-owl-script',
        IPSWB_BASE_URL . 'assets/js/public/owl.carousel.min.js',
        array(),
        1,
        true
      );

      wp_deregister_script('ip-bxslider-script');
      wp_enqueue_script(
        'ip-bxslider-script',
        IPSWB_BASE_URL . 'assets/js/public/jquery.bxslider.min.js',
        array(),
        1,
        true
      );*/

			wp_deregister_script('ipswb-admin-script');
			wp_enqueue_script(
				'ipswb-admin-script',
				IPSWB_BASE_URL . 'assets/js/admin.js',
				array( 'jquery' ),
				1,
				true
			);
		}

		//}}
		//{{ adminGlobalScript

		/**
		 * Add javascript file to all pages
		 *
		 * @return void
		 */
		public static function adminGlobalScript()
		{
			wp_deregister_script('ipswb-admin-global-script');
			wp_enqueue_script(
				'ipswb-admin-global-script',
				IPSWB_BASE_URL . 'assets/js/admin-global.min.js',
				array( 'jquery' ),
				1,
				true
			);
		}

		//}}
		//{{ publicStyle

		/**
		 * Print public style
		 *
		 * @return void
		 */
		public static function publicStyle()
		{
			global $post;

			//Set google font
      $fonts = array( 'roboto' );
      //
      //Get all contents
      $args = array(
        'orderby'        => 'post_title',
        'order'          => 'DESC', 
        'post_type'      => 'ipswb_boxes',
        'post_status'    => array('publish'),
        'posts_per_page' => -1,
        'paged'          => 1
      );
      $query  = new WP_Query;
      $slides = $query->query( $args );
      foreach( $slides as $slide ) 
      {
        $setting = new IPSwb_Setting( $slide->ID, '__ipswb_boxes_setting' );
        $style   = false;
	      if ( $styleId = $setting->getSetting( 'style' ) ) {
	        $style = get_post( $styleId );
	      }
	      if ( $style ) 
	      {
	      	$styleSetting = new IPSwb_Setting( $style->ID, '__ipswb_style_setting' );

	        $fonts[] = $styleSetting->getSetting( 'title_font_family', 'roboto' );
	        $fonts[] = $styleSetting->getSetting( 'desc_font_family', 'roboto' );
	        $fonts[] = $styleSetting->getSetting( 'footer_font_family', 'roboto' );
	      }
      }
      $fonts = array_unique( $fonts );
      $fams  = array();
      
      $links = IPSwb_Font::getLinks();
      foreach( $fonts as $font ) 
      {
        if ( array_key_exists( $font, $links )) 
        {
          $fams[] = $links[$font];
        }
      }
      $families = implode( '|', $fams );
      
      $fontUrl = 'http://fonts.googleapis.com/css?family=' . $families;
      echo '<link id="ipswb-font" href="' . $fontUrl . '" rel="stylesheet" type="text/css">';
		?>
			<script type="text/javascript">
				var ipswb_ajaxurl	= "<?php echo admin_url( 'admin-ajax.php' ); ?>";
				var ipswb_img_url	= '<?php echo IPSWB_BASE_URL . 'assets/img/'; ?>';
				var ipswb_post_id	= '<?php echo $post->ID; ?>';
			</script>

			<?php
			wp_enqueue_style('ip-owl-style');
			wp_deregister_style( 'ip-owl-style' );
			wp_register_style(
				'ip-owl-style',
				IPSWB_BASE_URL . 'assets/css/owl.carousel.css',
				false,
				null
			);
			wp_enqueue_style('ip-owl-style');

			wp_enqueue_style('ip-bxslider-style');
			wp_deregister_style( 'ip-bxslider-style' );
			wp_register_style(
				'ip-bxslider-style',
				IPSWB_BASE_URL . 'assets/css/jquery.bxslider.css',
				false,
				null
			);
			wp_enqueue_style('ip-bxslider-style');

			wp_enqueue_style('ipswb-public-style');
			wp_deregister_style( 'ipswb-public-style' );
			wp_register_style(
				'ipswb-public-style',
				IPSWB_BASE_URL . 'assets/css/public.min.css',
				false,
				null
			);
			wp_enqueue_style('ipswb-public-style');
			?>

		<?php
		}

		//}}
		//{{ publicScript

		/**
		 * Print public script
		 *
		 * @return void
		 */
		public static function publicScript()
		{
			wp_enqueue_script('jquery');

			wp_deregister_script('jquery-ui');
			wp_register_script(
				'jquery-ui',
				"http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jqueryui/1.10.4/jquery-ui.min.js",
				false,
				null
			);
			wp_enqueue_script('jquery-ui');

			wp_deregister_script('ipswb-public-script');
			wp_enqueue_script(
				'ipswb-public-script',
				IPSWB_BASE_URL . 'assets/js/public.min.js',
				array( 'jquery' ),
				1,
				true
			);

      wp_deregister_script('ip-velocity-script');
      wp_enqueue_script(
        'ip-velocity-script',
        IPSWB_BASE_URL . 'assets/js/public/velocity.min.js',
        array(),
        1,
        true
      );

      wp_deregister_script('ip-velocity-ui-script');
      wp_enqueue_script(
        'ip-velocity-ui-script',
        IPSWB_BASE_URL . 'assets/js/public/velocity.ui.js',
        array(),
        1,
        true
      );

      wp_deregister_script('ip-owl-script');
      wp_enqueue_script(
        'ip-owl-script',
        IPSWB_BASE_URL . 'assets/js/public/owl.carousel.min.js',
        array(),
        1,
        true
      );

      wp_deregister_script('ip-bxslider-script');
      wp_enqueue_script(
        'ip-bxslider-script',
        IPSWB_BASE_URL . 'assets/js/public/jquery.bxslider.min.js',
        array(),
        1,
        true
      );

      /*wp_deregister_script('ip-flexslider-script');
      wp_enqueue_script(
        'ip-flexslider-script',
        IPSWB_BASE_URL . 'assets/js/public/jquery.flexslider-min.js',
        array(),
        1,
        true
      );*/
		}
		//}}
	}
}
