<?php
if ( ! class_exists( 'IPSwb_Factory' ))
{
  /**
   * Widget factory class
   *
   * @package wp-slideshow-master
   * @author InstaProduct
   * @link http://insta-product.com/
   */

  class IPSwb_Factory extends IPSwb_Viewer
  {
    //{{ parameters

    /**
     * Take slide 
     *
     * @var object
     */
    public $slide;

    //}}
    //{{ __construct

    /**
     * Class constructor
     *
     * @param  array $atts
     * @return void
     */
    public function __construct( $atts = array() )
    {
      $slide = false;
      if ( ! empty( $atts['slide'] )) {
        $slideId = absint( $atts['slide'] );
        $slide   = get_post( $slideId );
      }
      $this->slide = $slide;
    }

    //}}
    //{{ render

    /**
     * Render page
     *
     * @return string
     */
    public function render()
    {
      if ( ! $this->slide ) {
        return '';
      }
      $slide   = $this->slide;

      //Check promo slide
      //$slide   = $this->_checkPromoSlide( $slide );
      $setting = new IPSwb_Setting( $slide->ID, '__ipswb_boxes_setting' );

      //
      //Check style
      $style = false;
      if ( $styleId = $setting->getSetting( 'style' ) ) {
        $style = get_post( $styleId );
      }
      if ( ! $style ) {
        return '';
      }
      $styleSetting = new IPSwb_Setting( $style->ID, '__ipswb_style_setting' );

      //
      //Try get boxes
      if ( ! $boxes = $this->_getSlideshowBoxes( $slide->ID ) ) {
        return '';
      }

      //
      //Check status
      if ( $setting->getSetting( 'status', 'true' ) == 'false' ) {
        return '';
      }

      //
      //Check restricted
      global $user_ID;
      $restricted = $setting->getSetting( 'restricted', 'false' );
      if ( empty( $user_ID ) && $restricted == 'true' ) {
        return '';
      }
      
      $this->setting      = $setting;
      $this->style        = $style;
      $this->styleSetting = $styleSetting;
      $this->boxes        = $boxes;

      //Render view
      ob_start();
      $this->view( 'front/main' );
      $output = ob_get_contents();
      ob_end_clean();

      return $output;
    }

    //}}
    //{{ preview

    /**
     * Bar preview viewer
     *
     * @param  array $slide
     * @return void
     */
    public function preview( $slide )
    {
      $output = '';
      if ( $slide )
      {
        $setting = new IPSwb_Setting( $slide->ID, '__ipswb_boxes_setting' );

        //
        //Check style
        $style = false;
        if ( $styleId = $setting->getSetting( 'style' ) ) {
          $style = get_post( $styleId );
        }
        if ( ! $style ) {
          return '';
        }
        $styleSetting = new IPSwb_Setting( $style->ID, '__ipswb_style_setting' );

        //
        //Try get boxes
        if ( ! $boxes = $this->_getSlideshowBoxes( $slide->ID ) ) {
          return '';
        }

        //
        //Check status
        if ( $setting->getSetting( 'status', 'true' ) == 'false' ) {
          return '';
        }

        //
        //Check restricted
        global $user_ID;
        $restricted = $setting->getSetting( 'restricted', 'false' );
        if ( empty( $user_ID ) && $restricted == 'true' ) {
          return '';
        }
        
        $this->slide        = $slide;
        $this->setting      = $setting;
        $this->style        = $style;
        $this->styleSetting = $styleSetting;
        $this->boxes        = $boxes;

        //Render view
        ob_start();
        $this->view( 'front/main' );
        $output = ob_get_contents();
        ob_end_clean();
      }
      return $output;
    }

    //}}
    //{{ _getSlideshowBoxes

    /**
     * Get slideshow boxes
     *
     * @param  ind $slideId
     * @return void
     */
    protected function _getSlideshowBoxes( $slideId )
    {
      $args = array(
          'orderby'        => 'post_date',
          'order'          => 'DESC',
          'post_type'      => 'ipswb_box',
          'post_status'    => array('publish','draft'),
          'post_parent'    => $slideId,
          'posts_per_page' => -1,
          'paged'          => 1
      );
      $query  = new WP_Query;
      $result = $query->query( $args );

      return $result;
    }

    //}}
    //{{ getYoutubeUrl

    /**
     * Get youtube url
     *
     * @return string
     */
    public function getYoutubeUrl( $setting )
    {
      $url  = $setting->getSetting( 'youtube_url' );
      $time = $setting->getSetting( 'youtube_start', 0 );
      $auto = $setting->getSetting( 'video_autoplay', 'false' );
      if ( $url )
      {
        if ( strpos( $url, 'embed' ) === false ) {
          if ( strpos( $url, 'watch' ) !== false ) {
            $id     = '';
            $parsed = parse_url( $url );
            if ( ! empty( $parsed['query'] )) {
                parse_str( $parsed['query'], $args );
                if ( ! empty( $args['v'] )) {
                    $id = $args['v'];
                }
            }
            $url = 'http://youtube.com/embed/' . $id;
          }
          elseif ( strpos( $url, 'youtu.be' ) !== false ) {
            $id     = '';
            $parsed = parse_url( $url );
            if ( ! empty( $parsed['path'] )) {
              $id = trim( $parsed['path'], '/' );
            }
            $url = 'http://youtube.com/embed/' . $id;
          }
        }
        /*if ( $auto == 'true' ) {
          $astart = 1;
        } else {
          $astart = 0;
        }*//*
        $astart = 0;
        $url .= '?autoplay=' . $astart . '&rel=0';
        if ( ! empty( $time )) {
          $url .= '&start=' . $time;
        }*/
        $url .= '?rel=0';
        if ( ! empty( $time )) {
          $url .= '&start=' . $time;
        }
      }
      return $url;
    }

    //}}
    //{{ getShareLink

    /**
     * Get share link
     *
     * @param  string $type
     * @param  object $post
     * @return string
     */
    public function getShareLink( $type, $post )
    {
      $pagetitle = urlencode( $post->post_title );
      $pageurl   = urlencode( $this->_getPageLink( $post ) );
      $actions   =  array(
        'facebook'      => 'http://www.facebook.com/share.php?u=' . $pageurl,
        'twitter'       => 'https://twitter.com/share?url=' . $pageurl . '&text=' . $pagetitle,
        'googleplus'    => 'https://plusone.google.com/_/+1/confirm?hl=en&url=' . $pageurl,
        'pinterest'     => 'http://pinterest.com/pin/create/button/?url=' . $pageurl . '&media=&description=' . $pagetitle,
        'linkedin'      => 'http://www.linkedin.com/shareArticle?mini=true&url=' . $pageurl .'&title=' . $pagetitle,
        'tumblr'        => 'http://www.tumblr.com/share?v=3&u=' . $pageurl,
        'stumbleupon'   => 'http://www.stumbleupon.com/submit?url=' . $pageurl . '&title=' . $pagetitle,
        'digg'          => 'http://digg.com/submit?url=' . $pageurl . '&title=' . $pagetitle,
        'email'         => 'mailto:?subject=' . $pagetitle
      );
      $link = '#';
      if ( array_key_exists( $type, $actions )) {
        $link = $actions[$type];
      }
      return $link;
    }

    //}}
    //{{ checkStyle

    /**
     * Check style
     *
     * @param  object $post
     * @return string
     */
    public function checkStyle( $post )
    {
      global $ipswbSlideshowStyles;

      if ( empty( $ipswbSlideshowStyles )) {
        $ipswbSlideshowStyles = array();
      }

      if ( ! in_array( $post->ID, $ipswbSlideshowStyles )) {
        $ipswbSlideshowStyles[] = $post->ID;
        return false;
      }
      return true;
    }

    //}}
    //{{ checkModal

    /**
     * Check modal
     *
     * @param  object $post
     * @return string
     */
    public function checkModal( $post )
    {
      global $ipswbSlideshowModals;

      if ( empty( $ipswbSlideshowModals )) {
        $ipswbSlideshowModals = array();
      }

      if ( ! in_array( $post->ID, $ipswbSlideshowModals )) {
        $ipswbSlideshowModals[] = $post->ID;
        return false;
      }
      return true;
    }

    //}}
    //{{ _getPageLink

    /**
     * Get page link
     *
     * @param  object $page
     * @return string
     */
    protected function _getPageLink( $page )
    {
      if ( get_option( 'permalink_structure' ) )  {
        $base = get_option( '__ipswb_base_path', 'box-page' );
        $link = get_home_url() . "/$base/" . $page->post_name;
      } else {
        $link = get_home_url() . '/?box_id=' . $page->ID;
      }
      return $link;
    }

    //}}
    //{{ _checkPromoSlide

    /**
     * Check promo slideshow
     *
     * @param  object $slide
     * @return string
     */
    protected function _checkPromoSlide( $slide )
    {
      $now     = time();
      $setting = new IPSwb_Setting( $slide->ID, '__ipswb_boxes_setting' );

      $startDate = $setting->getSetting( 'promo_start_date' );
      $startTime = $setting->getSetting( 'promo_start_time' );
      $endDate   = $setting->getSetting( 'promo_end_date' );
      $endTime   = $setting->getSetting( 'promo_end_time' );

      if ( $startDate && $endDate )
      {
        $startStr = $startDate;
        if ( $startTime ) {
          $startStr .= ' ' . $startTime . ':00';
        } else {
          $startStr .= ' 00:00:00';
        }
        $start = strtotime( $startStr );

        $endStr = $endDate;
        if ( $endTime ) {
          $endStr .= ' ' . $endTime . ':00';
        } else {
          $endStr .= ' 00:00:00';
        }
        $end = strtotime( $endStr );

        if ( $now > $start && $now < $end ) 
        {
          $promoId = $setting->getSetting( 'promo_slideshow', 0 );
          $promo   = get_post( $promoId );
          if ( $promo ) {
            $slide = $promo;
          }
        }
      }
      return $slide;
    }

    //}}
  }
}
