<?php
/**
 * Class for create list box
 *
 * @package wp-slideshow-master
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPSwb_List_Box' )) 
{
  class IPSwb_List_Box extends IPSwb_List
  {
    //{{ properties

    /**
     * Take boxes id
     *
     * @var int
     */
    protected $_boxesId;

    //}}
    //{{ __construct

    /**
     * Class constructor
     *
     * @param  int $boxesId
     * @return void
     */
    public function __construct( $boxesId = 0 )
    {
      $this->_boxesId = absint( $boxesId );
      parent::__construct();
    }

    //}}
    //{{ _getData

    /**
     * Get data
     *
     * @return void
     */
    protected function _getData()
    {
      $page     = $this->_page;
      $per_page = $this->_perPage;
      $args = array(
          'orderby'        => 'post_date',
          'order'          => 'DESC',
          'post_type'      => 'ipswb_box',
          'post_status'    => array('publish','draft'),
          'post_parent'    => $this->_boxesId,
          'posts_per_page' => $per_page,
          'paged'          => $page
      );
      $query = new WP_Query;
      $this->_result = $query->query( $args );
      $this->_query  = $query;
      $this->_total  = $query->found_posts;
      $this->_total_page = $this->_getTotalPage();
      return $this->_result;
    }

    //}}
    //{{ _getItemAction

    /**
     * Get item action
     *
     * @param  object $item
     * @param  int    $index
     * @return string
     */
    protected function _getItemAction( $item, $index )
    {
      $itemId  = $this->_getListItemId( $item );
      $result  =
        '<div class="col-sm-6">' .
          '<div class="ipswb-item-action ipswb-clear text-right">' .
            $this->_getItemStat( $item, $index ) .

            '<div class="ipswb-item-nav ipswb-fademenu">' .
              '<div class="ipswb-fademenu-inner">' .
                '<div class="ipswb-nav-label ipswb-fademenu-button">' .
                  '<a class="ipswb-menu-link" href="#"><i class="ipswb-fa ipswb-fa-bars"></i></a>' .
                '</div>' .
                '<ul class="ipswb-submenu ipswb-fademenu-content">' .
                  '<li>' .
                    '<a href="' . $this->_getLinkEdit( $item ) . '" class="ipswb-btn ipswb-btn-xs ipswb-btn-success">' .
                      '<i class="ipswb-fa ipswb-fa-pencil"></i>' .
                       __( 'Edit Box', IPSWB_SLUG ) .
                    '</a>' .
                  '</li>' .
                  '<li>' .
                    '<a href="#" class="ipswb-btn ipswb-btn-xs ipswb-btn-danger ipswb-item-box-delete" data-boxes-id="' . $this->_boxesId . '" data-id="' . $itemId . '">' .
                      '<i class="ipswb-fa ipswb-fa-trash"></i>' .
                      __( 'Delete Box', IPSWB_SLUG ) .
                    '</a>' .
                  '</li>' .
                '</ul>' .
              '</div>' .
            '</div>' .
          '</div>' .
        '</div>';
      return $result;
    }

    //}}
    //{{ _getLinkEdit

    /**
     * Get link edit
     *
     * @param  object $item
     * @return string
     */
    protected function _getLinkEdit( $item )
    {
      $link = admin_url() . 'admin.php?page=' . IPSWB_PAGENAME . '&action=editbox&id=' . $item->ID . '&slide_id=' . $this->_boxesId;
      return $link;
    }

    //}}
    //{{ _getPaginationLink

    /**
     * Get pagination link
     *
     * @param  int $page
     * @return string
     */
    protected function _getPaginationLink( $page )
    {
      $boxesId = 0;
      $link = admin_url() . 'admin.php?page=' . IPSWB_PAGENAME . '&id=' . $this->_boxesId . '&paged=' . $page;
      return $link;
    }

    //}}
  }

}