<?php
/**
 * Class model slide statistic
 *
 * @package visitor-converter
 * @author InstaProduct
 * @link http://insta-product.com/
 */

if ( ! class_exists( 'IPSwb_Model_Stat' )) {

  /**
   * Class model slide statatistic
   */
  class IPSwb_Model_Stat
  {
		/**
		 * Get All Stats
		 *
		 * @return array
		 */
		public function getAllStats()
		{
			global $wpdb;

			$table  = $wpdb->prefix . 'ipswb_stat';
			$query  = "
					SELECT
						SUM( `stat_slide_view` )  as `slide_views`,
						SUM( `stat_media_view` )  as `media_views`,
						SUM( `stat_detail_view` ) as `detail_views`,
						SUM( `stat_share` ) 			as `shares`
					FROM $table
			";
			$results = $wpdb->get_row( $query );
			return $results;
		}

		/**
		 * Get Stats
		 *
		 * @return int   $slideId
		 * @return array
		 */
		public function getStats( $slideId )
		{
			global $wpdb;

			$slideId = absint( $slideId );
			$table   = $wpdb->prefix . 'ipswb_stat';
			$query   = "
					SELECT * FROM $table
					WHERE
							slide_id = $slideId
			";
			$results = $wpdb->get_row( $query );
			return $results;
		}

		/**
     * Get stat by slide date
     *
     * @param  int $slideId
     * @return array
     */
    public function getStatBySlide( $slideId )
    {
      global $wpdb;

      $slideId = absint( $slideId );
      $table   = $wpdb->prefix . 'ipswb_stat';
      $sql     = "
          SELECT *
          FROM `$table`
          WHERE slide_id = $slideId
      ";
      $results = $wpdb->get_row( $sql );
      
      return $results;
    }

		/**
     * Do save statistic
     *
     * @param object $slide
     * @param string $type
     * @param int    $count
     * @return void
     */
    public function saveStat( $slide, $type, $count = 1 )
    {
      $_types = array(
        'slide_view',
        'media_view',
        'detail_view',
        'share'
      );
      $key = 'stat_';
      if ( in_array( $type, $_types )) {
        $key .= $type;
      }
      $data = array();
      if ( $stat = $this->getStatBySlide( $slide->ID ))
      {
        $ccount = 0;
        if ( isset( $stat->$key )) {
          $ccount = $stat->$key;
        }
        $data[$key] = $ccount + $count;
        $this->updateStat( $stat->stat_id, $data );
      }
      else {
        $data['slide_id']  = $slide->ID;
        $data['stat_date'] = date( 'Y-m-d 00:00:00' );
        $data[$key]        = $count;
        $this->insertStat( $data );
      }
    }

    /**
     * Get statistic data
     *
     * @return array
     */
    public function getStatisticData( $slideId, $type, $start = null, $end = null )
    {
      global $wpdb;

      $slideId = absint( $slideId );
      $table   = $wpdb->prefix . 'ipswb_stat';
      $query   = "
          SELECT
            DATE_FORMAT(stat_date, '%Y-%m-%d') AS gdate,";
			      //Type value
			      if ( $type == 'slide_view' ) {
			        $query .= 'SUM(stat_slide_view) AS value';
			      } elseif ( $type == 'media_view' ) {
			        $query .= 'SUM(stat_media_view) AS value';
			      } elseif ( $type == 'detail_view' ) {
			        $query .= 'SUM(stat_detail_view) AS value';
			      } elseif ( $type == 'share' ) {
			        $query .= 'SUM(stat_share) AS value';
			      }
			      $query .= " FROM $table
			                  WHERE slide_id = $slideId";

      if ( ! empty( $start ) && ! empty( $end ))
      {
        if ( $start == $end ) {
          $query .= " AND DATE_FORMAT( stat_date, '%Y-%m-%d' ) = '$start'";
        } else {
          $query .= " AND stat_date BETWEEN '$start' AND '$end'";
        }
      }
      elseif ( ! empty( $start )) {
        $query .= " AND DATE_FORMAT( stat_date, '%Y-%m-%d' ) = '$start'";
      }
      elseif ( ! empty( $end )) {
        $query .= " AND DATE_FORMAT( stat_date, '%Y-%m-%d' ) = '$end'";
      }
      $query .= " GROUP BY gdate";
      
      $results = $wpdb->get_results( $query );
      return $results;
    }

		/**
		 * Insert Stat
		 *
		 * @param  array $data
		 * @param  array $format
		 * @return void
		 */
		public function insertStat( $data, $format = array() )
		{
				global $wpdb;
				$table  = $wpdb->prefix . 'ipswb_stat';
				$data   = (array)$data;

				$result = $wpdb->insert( $table, $data, $format );
				if ( $result ) {
						return $wpdb->insert_id;
				}
				return false;
		}

		/**
		 * Update Stat
		 *
		 * @param  int   $id
		 * @param  array $data
		 * @return void
		 */
		public function updateStat( $id, $data )
		{
				global $wpdb;
				$table  = $wpdb->prefix . 'ipswb_stat';
				$data   = (array)$data;
				$where  = array(
						'stat_id' => absint( $id )
				);
				$result = $wpdb->update( $table, $data, $where );
				return $result;
		}

		/**
		 * Delete Stat
		 *
		 * @param  int   $id
		 * @return void
		 */
		public function deleteStat( $id )
		{
			global $wpdb;
			$table  = $wpdb->prefix . 'ipswb_stat';
			$where  = array(
					'stat_id' => absint( $id )
			);
			$result = $wpdb->delete( $table, $where );
			return $result;
		}
	}
}
